==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PodMonitorBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodMonitorBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PodMonitorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PodMonitor,io.fabric8.openshift.api.model.monitoring.v1.PodMonitorBuilder>{
  public PodMonitorBuilder() {
    this(false);
  }
  public PodMonitorBuilder(java.lang.Boolean validationEnabled) {
    this(new PodMonitor(), validationEnabled);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent) {
    this(fluent, false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodMonitor(), validationEnabled);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance) {
    this(fluent, instance, false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance) {
    this(instance,false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PodMonitor build() {
    PodMonitor buildable = new PodMonitor(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodMonitorBuilder that = (PodMonitorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PodMonitorBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodMonitorBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PodMonitorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PodMonitor,io.fabric8.openshift.api.model.monitoring.v1.PodMonitorBuilder>{
  public PodMonitorBuilder() {
    this(false);
  }
  public PodMonitorBuilder(java.lang.Boolean validationEnabled) {
    this(new PodMonitor(), validationEnabled);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent) {
    this(fluent, false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodMonitor(), validationEnabled);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance) {
    this(fluent, instance, false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance) {
    this(instance,false);
  }
  public PodMonitorBuilder(io.fabric8.openshift.api.model.monitoring.v1.PodMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PodMonitorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PodMonitor build() {
    PodMonitor buildable = new PodMonitor(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodMonitorBuilder that = (PodMonitorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
